## GO analysis on orthologous peaks in mouse and dunnart
## Input is liftOver peaks in mouse coordinates from comparePeaks.R

## Load packages
library(clusterProfiler)
library(data.table)
library(enrichplot)
library(GOSemSim)
library(ChIPseeker)
library(TxDb.Mmusculus.UCSC.mm10.knownGene)
library(org.Mm.eg.db)
library(viridis)
library(ComplexHeatmap)
library(tidyverse)
library(ggplot2)
library(plyr)
library(UpSetR)
txdb <- TxDb.Mmusculus.UCSC.mm10.knownGene
mmGO = godata('org.Mm.eg.db', ont="BP") 

###################################################################################################
############################### GENE ONTOLOGY & PATHWAY ANALYSIS ##################################
###################################################################################################

compareOrthoPeaks <- function(bedList, dotplot, names, upsetPlot, mergedNames){
    bedFiles = list.files(bedList, pattern= "liftOver.bed", full.names=T) # create list of files in directory
    bedFiles = as.list(bedFiles)

    ## Annotate peaks
    peakAnnoList <- lapply(bedFiles, annotatePeak, TxDb=txdb,
                       tssRegion=c(-3000, 3000), verbose=FALSE, annoDb="org.Mm.eg.db")
    
    ## Make dataframe from upset plot
    df2 = lapply(peakAnnoList, function(x) as.data.frame(x@anno))
    subset = lapply(df2, function(x) x %>% dplyr::select(ENSEMBL) %>% as.data.table() %>% unique())
    names(subset) = names
    subset = Map(mutate, subset, stage = names(subset)) 
    merged <- subset %>% purrr::reduce(full_join, by = "ENSEMBL")  # join all dataframes by ensembl geneID
    merged[is.na(merged)] <- 0
    merged = as.data.frame(merged)
    geneId = merged$geneId
    colnames(merged) = mergedNames 
    upset.df = data.frame(lapply(merged[,2:8], function(x) as.numeric(x!="0")))
    rownames(upset.df) = geneId

    ## Upset plot
    pdf(upsetPlot)
    print(upset(upset.df, 
    nsets=7, order.by="freq", 
    number.angles = 45))
    dev.off()

    ## Make a background universe for GO enrichment testing
    ## Take the union of ALL genes with peaks for mouse and dunnart
    bedFiles = list.files(backgroundList, pattern= ".txt", full.names=T) # create list of files in directory
    bedFiles = as.list(bedFiles)
    data = lapply(bedFiles, function(x) fread(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA")))
    data = lapply(data, function(x) x=setnames(x, old="geneId", new="mouseensembl", skip_absent=TRUE) %>% as.data.table())
    genes = lapply(data, function(i) as.data.frame(i)$mouseensembl)
    genes = lapply(genes, function(x) bitr(x, fromType="ENSEMBL", toType="ENTREZID", OrgDb="org.Mm.eg.db"))
    bkg_genes = lapply(genes, function(i) as.data.frame(i)$ENTREZID)
    bkg_genes_union = Reduce(union, genes) 

    ## GO terms 
    genes = lapply(peakAnnoList, function(i) as.data.frame(i)$geneId)
    names(genes) = names
    go_cluster <- pairwise_termsim(
      setReadable(
      compareCluster(
        geneCluster = genes,
        fun = enrichGO, 
        ont="BP",
        keyType="ENTREZID", 
        pAdjustMethod = "fdr",
        pvalueCutoff = 0.001, 
        OrgDb = org.Mm.eg.db),
      OrgDb = org.Mm.eg.db, 
      keyType="ENTREZID"))

    ## Dotplot
    pdf(dotplot, width = 20, height = 10)
    print(dotplot(go_cluster) + 
    scale_color_viridis() + 
    theme(axis.text.x = element_text(angle = 45, hjust=1)))
    dev.off()

    return(genes)
}

names = c("E10", "E11", "E12", "E13", "E14", "E15", "dunnart")

all_promoters = compareOrthoPeaks(bedList = "GO_analysis/promoters", backgroundList = "../consensus/promoters/clustered", names = c("E10_mouse", "E10_combined", "E10_dunnart", "E11_mouse", "E11_combined", "E11_dunnart",
    "E12_mouse", "E12_combined", "E12_dunnart", "E13_mouse", "E13_combined", "E13_dunnart", 
    "E14_mouse", "E14_combined", "E14_dunnart", "E15_mouse", "E15_combined", "E15_dunnart"), mergedNames = c("geneId", "E10_mouse", "E10_combined", "E10_dunnart", "E11_mouse", "E11_combined", "E11_dunnart",
    "E12_mouse", "E12_combined", "E12_dunnart", "E13_mouse", "E13_combined", "E13_dunnart", 
    "E14_mouse", "E14_combined", "E14_dunnart", "E15_mouse", "E15_combined", "E15_dunnart"), dotplot = "promoter_dotplot_GOenrich.pdf", upsetPlot = "promoter_upsetPlot_GOenrich.pdf")

all.enhancers = compareOrthoPeaks(bedList = "GO_analysis/enhancers", names = c("E10_dunnart", "E10_mouse", "E10_combined", "E11_dunnart","E11_mouse", "E11_combined", 
     "E12_dunnart","E12_mouse", "E12_combined",  "E13_dunnart","E13_mouse", "E13_combined", "E14_dunnart", 
    "E14_mouse", "E14_combined",  "E15_dunnart", "E15_mouse","E15_combined"), mergedNames = c("geneId", "E10_dunnart", "E10_mouse", "E10_combined", "E11_dunnart","E11_mouse", "E11_combined", 
     "E12_dunnart","E12_mouse", "E12_combined",  "E13_dunnart","E13_mouse", "E13_combined", "E14_dunnart", 
    "E14_mouse", "E14_combined",  "E15_dunnart", "E15_mouse","E15_combined"), dotplot = "enhancer_dotplot_GOenrich.pdf", upsetPlot = "enhancer_upsetPlot_GOenrich.pdf")

enhancerSim = mclusterSim(all.enhancers, semData=mmGO, measure="Wang", combine="BMA")
pdf("enhancerGOSemSim_heatmap.pdf")
Heatmap(enhancerSim)
dev.off()

promoterSim = mclusterSim(all.promoters, semData=mmGO, measure="Wang", combine="BMA")
pdf("promoterGOSemSim_heatmap.pdf")
Heatmap(promoterSim)
dev.off()

## Now look at merged mouse peaks across all stages and compare to the dunnart

## 
bedFiles = list("GO_analysis/merged/dunnart_specific_mouse_merged_enhancerOverlapmm10_50bpsummits_backTOsmiCra_smiCraTOmm10.bed", "GO_analysis/merged/mouse_merged_enhancerOverlapmm10_50bpsummits_backTOsmiCra_smiCraTOmm10.bed", "GO_analysis/merged/mouse_specific_enhancer_overlap_50bpsummits.sorted.merged_mm10TOsmiCra_backTOmm10.bed")
bedFiles = list("GO_analysis/merged/dunnart_specific_mouse_merged_promoterOverlapmm10_50bpsummits_backTOsmiCra_smiCraTOmm10.bed", "GO_analysis/merged/mouse_merged_promoterOverlapmm10_50bpsummits_backTOsmiCra_smiCraTOmm10.bed", "GO_analysis/merged/mouse_specific_promoter_overlap_50bpsummits.sorted.merged_mm10TOsmiCra_backTOmm10.bed")

peakAnnoList <- lapply(bedFiles, annotatePeak, TxDb=txdb,
                       tssRegion=c(-3000, 3000), verbose=FALSE, annoDb="org.Mm.eg.db")

genes = lapply(peakAnnoList, function(i) as.data.frame(i)$geneId)
names(genes) = c("dunnart_biased", "common", "mouse_biased")
go_cluster <- simplify(
      setReadable(
      compareCluster(
        geneCluster = genes, 
        fun = enrichGO, 
        ont="BP", 
        keyType="ENTREZID", 
        pvalueCutoff = 0.01, 
        OrgDb = org.Mm.eg.db),
      OrgDb = org.Mm.eg.db, 
      keyType="ENTREZID"),
      cutoff=0.9, 
      by="p.adjust", 
      select_fun=min)

pdf("summary_enhancer_cnetplot_GOenrich.pdf")
print(cnetplot(go_cluster))
dev.off()

pdf("summary_enhancer_dotplot_GOenrich.pdf", width = 10, height = 8)
print(dotplot(go_cluster, showCategory = 15) + theme(axis.text.x = element_text(angle = 45, hjust=1)))
dev.off()





